@@ -10,7 +10,9 @@
 #include <spl.h>
 #include <libfdt.h>
 #include <nand.h>
+#include <stdio.h>
 #include <linux/io.h>
+#include <linux/printk.h>
 #include <../drivers/mtd/nand/denali.h>
 
 #include "init.h"
@@ -37,7 +39,7 @@ static int uniphier_set_fdt_file(void)
 	char dtb_name[256];
 	int buf_len = sizeof(dtb_name);
 
-	if (getenv("fdt_file"))
+	if (env_get("fdt_file"))
 		return 0;	/* do nothing if it is already set */
 
 	compat = fdt_stringlist_get(gd->fdt_blob, 0, "compatible", 0, NULL);
@@ -55,7 +57,7 @@ static int uniphier_set_fdt_file(void)
 
 	strncat(dtb_name, ".dtb", buf_len);
 
-	return setenv("fdt_file", dtb_name);
+	return env_set("fdt_file", dtb_name);
 }
 
 int board_late_init(void)
@@ -64,29 +66,35 @@ int board_late_init(void)
 
 	switch (uniphier_boot_device_raw()) {
 	case BOOT_DEVICE_MMC1:
-		printf("eMMC Boot\n");
-		setenv("bootmode", "emmcboot");
+		printf("eMMC Boot");
+		env_set("bootmode", "emmcboot");
 		break;
 	case BOOT_DEVICE_NAND:
-		printf("NAND Boot\n");
-		setenv("bootmode", "nandboot");
+		printf("NAND Boot");
+		env_set("bootmode", "nandboot");
 		nand_denali_wp_disable();
 		break;
 	case BOOT_DEVICE_NOR:
-		printf("NOR Boot\n");
-		setenv("bootmode", "norboot");
+		printf("NOR Boot");
+		env_set("bootmode", "norboot");
 		break;
 	case BOOT_DEVICE_USB:
-		printf("USB Boot\n");
-		setenv("bootmode", "usbboot");
+		printf("USB Boot");
+		env_set("bootmode", "usbboot");
 		break;
 	default:
-		printf("Unknown\n");
+		printf("Unknown");
 		break;
 	}
 
+	if (uniphier_have_internal_stm())
+		printf(" (STM: %s)",
+		       uniphier_boot_from_backend() ? "OFF" : "ON");
+
+	printf("\n");
+
 	if (uniphier_set_fdt_file())
-		printf("fdt_file environment was not set correctly\n");
+		pr_warn("fdt_file environment was not set correctly\n");
 
 	return 0;
 }
