@@ -19,8 +19,8 @@
 #include <tsec.h>
 #include <netdev.h>
 #include <fsl_esdhc.h>
-#ifdef CONFIG_BOOTCOUNT_LIMIT
-#include <asm/immap_qe.h>
+#if defined(CONFIG_BOOTCOUNT_LIMIT) && !defined(CONFIG_MPC831x)
+#include <linux/immap_qe.h>
 #include <asm/io.h>
 #endif
 
@@ -33,6 +33,7 @@ int checkcpu(void)
 	u32 pvr = get_pvr();
 	u32 spridr;
 	char buf[32];
+	int ret;
 	int i;
 
 	const struct cpu_type {
@@ -61,6 +62,10 @@ int checkcpu(void)
 
 	immr = (immap_t *)CONFIG_SYS_IMMR;
 
+	ret = prt_83xx_rsr();
+	if (ret)
+		return ret;
+
 	puts("CPU:   ");
 
 	switch (pvr & 0xffff0000) {
@@ -173,11 +178,7 @@ do_reset (cmd_tbl_t * cmdtp, int flag, int argc, char * const argv[])
 
 unsigned long get_tbclk(void)
 {
-	ulong tbclk;
-
-	tbclk = (gd->bus_clk + 3L) / 4L;
-
-	return tbclk;
+	return (gd->bus_clk + 3L) / 4L;
 }
 
 
