@@ -14,6 +14,8 @@
 #include <dm.h>
 #include <dm/platform_data/serial_coldfire.h>
 
+DECLARE_GLOBAL_DATA_PTR;
+
 void init_lcd(void)
 {
 	/* setup for possible K0108 lcd connected on the parallel port */
@@ -38,7 +40,7 @@ int checkboard(void)
 }
 
 /*
- * in initdram we are here executing from flash
+ * in dram_init we are here executing from flash
  * case 1:
  * is with no ACR/flash cache enabled
  * nop = 40ns (scope measured)
@@ -49,7 +51,7 @@ void fudelay(int usec)
 		asm volatile ("nop");
 }
 
-phys_size_t initdram(int board_type)
+int dram_init(void)
 {
 	u32 dramsize, RC;
 
@@ -99,7 +101,10 @@ phys_size_t initdram(int board_type)
 	out_be32(&dc->dacr0, 0x0000b344);
 	out_be32((u32 *)0x00000c00, 0xbeaddeed);
 
-	return get_ram_size(CONFIG_SYS_SDRAM_BASE, CONFIG_SYS_SDRAM_SIZE);
+	gd->ram_size = get_ram_size(CONFIG_SYS_SDRAM_BASE,
+				    CONFIG_SYS_SDRAM_SIZE);
+
+	return 0;
 }
 
 static struct coldfire_serial_platdata mcf5307_serial_plat = {
