@@ -2,7 +2,8 @@
  * SPDX-License-Identifier:	GPL-2.0+
  */
 
-#include <dm/uclass.h>
+#include <common.h>
+#include <dm.h>
 
 /* Firmware access is platform-dependent.  No generic code in uclass */
 UCLASS_DRIVER(firmware) = {
