@@ -752,13 +752,6 @@ unsigned long get_board_ddr_clk(void);
 #define CONFIG_MTD_DEVICE
 #define CONFIG_MTD_PARTITIONS
 #define CONFIG_FLASH_CFI_MTD
-#define MTDIDS_DEFAULT    "nor0=fe8000000.nor,nand0=fff800000.flash," \
-			  "spi0=spife110000.0"
-#define MTDPARTS_DEFAULT  "mtdparts=fe8000000.nor:1m(uboot),5m(kernel)," \
-			  "128k(dtb),96m(fs),-(user);"\
-			  "fff800000.flash:2m(uboot),9m(kernel),"\
-			  "128k(dtb),96m(fs),-(user);spife110000.0:" \
-			  "2m(uboot),9m(kernel),128k(dtb),-(user)"
 #endif
 
 /*
