@@ -8,11 +8,12 @@
 #ifndef __CONFIG_H
 #define __CONFIG_H
 
-#define CONFIG_IDENT_STRING		" odroid-c2"
+#define CONFIG_MISC_INIT_R
 
 /* Serial setup */
 #define CONFIG_CONS_INDEX		0
-#define CONFIG_BAUDRATE			115200
+
+#define MESON_FDTFILE_SETTING "fdtfile=amlogic/meson-gxbb-odroidc2.dtb\0"
 
 #include <configs/meson-gxbb-common.h>
 
