@@ -5,15 +5,15 @@
  * SPDX-License-Identifier:     GPL-2.0+
  */
 
-#ifndef _P2371_0000_H
-#define _P2371_0000_H
+#ifndef _P2371_2180_H
+#define _P2371_2180_H
 
 #include <linux/sizes.h>
 
 #include "tegra210-common.h"
 
 /* High-level configuration options */
-#define CONFIG_TEGRA_BOARD_STRING	"NVIDIA P2371-0000"
+#define CONFIG_TEGRA_BOARD_STRING	"NVIDIA P2371-2180"
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTA
@@ -22,7 +22,6 @@
 #define CONFIG_SYS_I2C_TEGRA
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
-#define CONFIG_ENV_IS_IN_MMC
 #define CONFIG_SYS_MMC_ENV_DEV		0
 #define CONFIG_SYS_MMC_ENV_PART		2
 #define CONFIG_ENV_OFFSET		(-CONFIG_ENV_SIZE)
@@ -33,16 +32,18 @@
 #define CONFIG_SPI_FLASH_SIZE		(4 << 20)
 
 /* USB2.0 Host support */
-#define CONFIG_USB_EHCI
 #define CONFIG_USB_EHCI_TEGRA
 
 /* USB networking support */
-#define CONFIG_USB_HOST_ETHER
-#define CONFIG_USB_ETHER_ASIX
+
+/* PCI host support */
 
 /* General networking support */
 
 #include "tegra-common-usb-gadget.h"
 #include "tegra-common-post.h"
 
-#endif /* _P2371_0000_H */
+/* Crystal is 38.4MHz. clk_m runs at half that rate */
+#define COUNTER_FREQUENCY	19200000
+
+#endif /* _P2371_2180_H */
