@@ -2,7 +2,7 @@
  * include/configs/rcar-gen3-common.h
  *	This file is R-Car Gen3 common configuration file.
  *
- * Copyright (C) 2015 Renesas Electronics Corporation
+ * Copyright (C) 2015-2017 Renesas Electronics Corporation
  *
  * SPDX-License-Identifier: GPL-2.0+
  */
@@ -12,21 +12,12 @@
 
 #include <asm/arch/rmobile.h>
 
-#define CONFIG_CMD_DFL
-#define CONFIG_CMD_SDRAM
-#define CONFIG_CMD_FAT
-#define CONFIG_CMD_EXT2
-#define CONFIG_CMD_EXT4
-#define CONFIG_CMD_EXT4_WRITE
-#define CONFIG_CMD_FDT
-
 #define CONFIG_REMAKE_ELF
 
 /* boot option */
 #define CONFIG_SUPPORT_RAW_INITRD
 
 /* Support File sytems */
-#define CONFIG_FAT_WRITE
 #define CONFIG_SUPPORT_VFAT
 #define CONFIG_FS_EXT4
 #define CONFIG_EXT4_WRITE
@@ -35,33 +26,47 @@
 #define CONFIG_SETUP_MEMORY_TAGS
 #define CONFIG_INITRD_TAG
 #define CONFIG_CMDLINE_EDITING
-#define CONFIG_OF_LIBFDT
-
-#define CONFIG_BAUDRATE		115200
 
 #undef	CONFIG_SHOW_BOOT_PROGRESS
 
 #define CONFIG_ARCH_CPU_INIT
 
-#define CONFIG_SH_GPIO_PFC
-
 /* console */
-
+#define CONFIG_SYS_CBSIZE		2048
+#define CONFIG_SYS_BARGSIZE		CONFIG_SYS_CBSIZE
 #define CONFIG_SYS_LONGHELP
-#define CONFIG_SYS_CBSIZE		256
-#define CONFIG_SYS_PBSIZE		256
-#define CONFIG_SYS_MAXARGS		16
-#define CONFIG_SYS_BARGSIZE		512
+#define CONFIG_SYS_MAXARGS		64
 #define CONFIG_SYS_BAUDRATE_TABLE	{ 115200, 38400 }
 
 /* MEMORY */
-#define CONFIG_SYS_TEXT_BASE		0x49000000
-#define CONFIG_SYS_INIT_SP_ADDR		(CONFIG_SYS_TEXT_BASE + 0x7fff0)
+#define CONFIG_SYS_TEXT_BASE		0x50000000
+#define CONFIG_SYS_INIT_SP_ADDR		CONFIG_SYS_TEXT_BASE
 
-#define CONFIG_SYS_SDRAM_BASE		(0x48000000)
-#define CONFIG_SYS_SDRAM_SIZE		(1024u * 1024 * 1024 - 0x08000000)
-#define CONFIG_SYS_LOAD_ADDR		(0x48080000)
-#define CONFIG_NR_DRAM_BANKS		1
+#define DRAM_RSV_SIZE			0x08000000
+#if defined(CONFIG_R8A7795)
+#define CONFIG_NR_DRAM_BANKS		4
+#define PHYS_SDRAM_1			(0x40000000 + DRAM_RSV_SIZE)
+#define PHYS_SDRAM_1_SIZE		(0x40000000u - DRAM_RSV_SIZE)
+#define PHYS_SDRAM_2			0x500000000
+#define PHYS_SDRAM_2_SIZE		0x40000000u
+#define PHYS_SDRAM_3			0x600000000
+#define PHYS_SDRAM_3_SIZE		0x40000000u
+#define PHYS_SDRAM_4			0x700000000
+#define PHYS_SDRAM_4_SIZE		0x40000000u
+#define CONFIG_SYS_SDRAM_BASE		PHYS_SDRAM_1
+#define CONFIG_SYS_SDRAM_SIZE		PHYS_SDRAM_1_SIZE
+#elif defined(CONFIG_R8A7796)
+#define CONFIG_NR_DRAM_BANKS		2
+#define PHYS_SDRAM_1			(0x40000000 + DRAM_RSV_SIZE)
+#define PHYS_SDRAM_1_SIZE		(0x80000000u - DRAM_RSV_SIZE)
+#define PHYS_SDRAM_2			0x0600000000
+#define PHYS_SDRAM_2_SIZE		0x80000000u
+#define CONFIG_SYS_SDRAM_BASE		PHYS_SDRAM_1
+#define CONFIG_SYS_SDRAM_SIZE		PHYS_SDRAM_1_SIZE
+#endif
+#define CONFIG_SYS_LOAD_ADDR		0x48080000
+#define CONFIG_VERY_BIG_RAM
+#define CONFIG_MAX_MEM_MAPPED		CONFIG_SYS_SDRAM_SIZE
 
 #define CONFIG_SYS_MONITOR_BASE		0x00000000
 #define CONFIG_SYS_MONITOR_LEN		(256 * 1024)
@@ -78,13 +83,9 @@
 	"fdt_high=0xffffffffffffffff\0"	\
 	"initrd_high=0xffffffffffffffff\0"
 
-#define CONFIG_BOOTARGS	\
-	"console=ttySC0,115200 rw root=/dev/nfs "	\
-	"nfsroot=192.168.0.1:/export/rfs ip=192.168.0.20"
-
 #define CONFIG_BOOTCOMMAND	\
 	"tftp 0x48080000 Image; " \
-	"tftp 0x48000000 Image-r8a7795-salvator-x.dtb; " \
+	"tftp 0x48000000 Image-"CONFIG_DEFAULT_FDT_FILE"; " \
 	"booti 0x48080000 - 0x48000000"
 
 #endif	/* __RCAR_GEN3_COMMON_H */
