@@ -150,6 +150,8 @@ enum {
 	DM_TESTF_SCAN_PDATA	= 1 << 0,	/* test needs platform data */
 	DM_TESTF_PROBE_TEST	= 1 << 1,	/* probe test uclass */
 	DM_TESTF_SCAN_FDT	= 1 << 2,	/* scan device tree */
+	DM_TESTF_FLAT_TREE	= 1 << 3,	/* test needs flat DT */
+	DM_TESTF_LIVE_TREE	= 1 << 4,	/* needs live device tree */
 };
 
 /* Declare a new driver model test */
