@@ -1,5 +1,5 @@
 /*
- * U-boot - linkage.h
+ * U-Boot - linkage.h
  *
  * Copyright (c) 2005-2007 Analog Devices Inc.
  *
@@ -10,7 +10,11 @@
 #define _LINUX_LINKAGE_H
 
 #include <asm/linkage.h>
-#include <linux/config.h>
+
+/* Some toolchains use other characters (e.g. '`') to mark new line in macro */
+#ifndef ASM_NL
+#define ASM_NL		 ;
+#endif
 
 #ifdef __cplusplus
 #define CPP_ASMLINKAGE		extern "C"
@@ -18,7 +22,9 @@
 #define CPP_ASMLINKAGE
 #endif
 
+#ifndef asmlinkage
 #define asmlinkage CPP_ASMLINKAGE
+#endif
 
 #define SYMBOL_NAME_STR(X)	#X
 #define SYMBOL_NAME(X)		X
@@ -42,11 +48,15 @@
 #define ALIGN_STR		__ALIGN_STR
 
 #define LENTRY(name) \
-	ALIGN; \
+	ALIGN ASM_NL \
 	SYMBOL_NAME_LABEL(name)
 
 #define ENTRY(name) \
-	.globl SYMBOL_NAME(name); \
+	.globl SYMBOL_NAME(name) ASM_NL \
+	LENTRY(name)
+
+#define WEAK(name) \
+	.weak SYMBOL_NAME(name) ASM_NL \
 	LENTRY(name)
 
 #ifndef END
@@ -56,7 +66,7 @@
 
 #ifndef ENDPROC
 #define ENDPROC(name) \
-	.type name STT_FUNC; \
+	.type name STT_FUNC ASM_NL \
 	END(name)
 #endif
 
