@@ -114,6 +114,13 @@ struct video_ops {
  */
 int video_reserve(ulong *addrp);
 
+/**
+ * video_clear() - Clear a device's frame buffer to background color.
+ *
+ * @dev:	Device to clear
+ */
+void video_clear(struct udevice *dev);
+
 /**
  * video_sync() - Sync a device's frame buffer with its hardware
  *
